from setuptools import setup

setup(
    name='bone',
    version='0.1.0',
    description='',
    url='http://github.com/qe/bone',
    author='Alex Ismodes',
    author_email='helloemailmerighthere@gmail.com',
    license='MIT',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    keywords='bone',
    packages=['bone'],
    install_requires=[''],
    )
